@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 class TestCaLocale < Test::Unit::TestCase
@@ -9,7 +11,11 @@ class TestCaLocale < Test::Unit::TestCase
     Faker::Config.locale = nil
   end
 
-  def test_ca_methods
+  def test_ca_color_methods
+    assert Faker::Color.color_name.is_a? String
+  end
+
+  def test_ca_name_methods
     assert Faker::Name.female_first_name.is_a? String
     assert Faker::Name.female_prefix.is_a? String
     assert Faker::Name.male_first_name.is_a? String
@@ -17,6 +23,6 @@ class TestCaLocale < Test::Unit::TestCase
     assert Faker::Name.last_name.is_a? String
     assert Faker::Name.first_name.is_a? String
     assert Faker::Name.name.is_a? String
-    assert Faker::Color.name.is_a? String
+    assert Faker::Name.name_with_middle.is_a? String
   end
 end
