@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 class TestEnAuLocale < Test::Unit::TestCase
@@ -9,10 +11,7 @@ class TestEnAuLocale < Test::Unit::TestCase
     Faker::Config.locale = nil
   end
 
-  def test_au_methods_with_en_au_locale
-    assert Faker::Name.first_name.is_a? String
-    assert Faker::Name.last_name.is_a? String
-    assert Faker::Company.suffix.is_a? String
+  def test_en_au_address_methods
     assert Faker::Address.street_name.is_a? String
     assert Faker::Address.city.is_a? String
     assert Faker::Address.state_abbr.is_a? String
@@ -20,8 +19,14 @@ class TestEnAuLocale < Test::Unit::TestCase
     assert Faker::Address.default_country.is_a? String
   end
 
-  def test_en_au_default_country
-    assert_equal 'Australia', Faker::Address.default_country
+  def test_en_au_company_methods
+    assert Faker::Company.suffix.is_a? String
+  end
+
+  def test_en_au_name_methods
+    assert Faker::Name.first_name.is_a? String
+    assert Faker::Name.last_name.is_a? String
+    assert Faker::Name.name_with_middle.is_a? String
   end
 
   def test_aussie_mobiles_start_with_04
