@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 class TestEnPakLocale < Test::Unit::TestCase
@@ -11,16 +13,24 @@ class TestEnPakLocale < Test::Unit::TestCase
   end
 
   def test_en_pak_methods
-    assert Faker::Name.first_name.is_a? String
-    assert Faker::Name.last_name.is_a? String
     assert Faker::Address.state.is_a? String
     assert Faker::Address.default_country.is_a? String
-    assert Faker::Internet.free_email.is_a? String
-    assert Faker::Internet.domain_suffix.is_a? String
+    assert Faker::Address.postcode.is_a? String
+    assert_match(/\A(Pakistan|Islamic Republic of Pakistan)\z/, Faker::Address.default_country)
+  end
+
+  def test_en_pak_company_methods
     assert Faker::Company.suffix.is_a? String
   end
 
-  def test_en_pak_default_country
-    assert_match(/\A(Pakistan|Islamic Republic of Pakistan)\z/, Faker::Address.default_country)
+  def test_en_pak_internet_methods
+    assert Faker::Internet.free_email.is_a? String
+    assert Faker::Internet.domain_suffix.is_a? String
+  end
+
+  def test_en_pak_name_methods
+    assert Faker::Name.first_name.is_a? String
+    assert Faker::Name.last_name.is_a? String
+    assert Faker::Name.name_with_middle.is_a? String
   end
 end
