@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 class TestFaLocale < Test::Unit::TestCase
@@ -13,5 +15,6 @@ class TestFaLocale < Test::Unit::TestCase
     assert Faker::Name.first_name.is_a? String
     assert Faker::Name.last_name.is_a? String
     assert Faker::Name.prefix.is_a? String
+    assert Faker::Name.name_with_middle.is_a? String
   end
 end
