@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 class TestSeeding < Test::Unit::TestCase
@@ -5,12 +7,12 @@ class TestSeeding < Test::Unit::TestCase
 
   def test_deterministic
     Faker::Config.random = Random.new(5)
-    first_random = Faker::Number.number(100_000)
+    first_random = Faker::Number.number(digits: 100_000)
     Faker::Config.random = Random.new(5)
-    second_random = Faker::Number.number(100_000)
+    second_random = Faker::Number.number(digits: 100_000)
     Faker::Config.random = Random.new
     Faker::Config.random = nil
-    third_random = Faker::Number.number(100_000)
+    third_random = Faker::Number.number(digits: 100_000)
 
     assert first_random == second_random
     # Tiny chance this will fail randomly if the unseeded Random just so
